@@ -1,3 +1,4 @@
+from dagster import DagsterInvariantViolationError, check
 from dagster_pandas.constraints import (
     CategoricalColumnConstraint,
     ColumnDTypeFnConstraint,
@@ -18,8 +19,6 @@ from pandas.core.dtypes.common import (
     is_string_dtype,
 )
 
-from dagster import DagsterInvariantViolationError, check
-
 PANDAS_NUMERIC_TYPES = {"int64", "float"}
 
 
@@ -257,6 +256,7 @@ class PandasColumn:
         unique=False,
         ignore_missing_vals=False,
         is_required=None,
+        tz=None,
     ):
         """
         Simple constructor for PandasColumns that expresses datetime constraints on 'datetime64[ns]' dtypes.
@@ -275,11 +275,28 @@ class PandasColumn:
                 only evaluate non-null data. Ignore_missing_vals and non_nullable cannot both be True.
             is_required (Optional[bool]): Flag indicating the optional/required presence of the column.
                 If the column exists the validate function will validate the column. Default to True.
+            tz (Optional[str]): Required timezone for values eg: tz='UTC', tz='Europe/Dublin', tz='US/Eastern'.
+                Defaults to None, meaning naive datetime values.
         """
+        if tz is None:
+            datetime_constraint = ColumnDTypeInSetConstraint({"datetime64[ns]"})
+        else:
+            datetime_constraint = ColumnDTypeInSetConstraint({f"datetime64[ns, {tz}]"})
+            # One day more/less than absolute min/max to prevent OutOfBoundsDatetime errors when converting min/max to be tz aware
+            if min_datetime.tz_localize(None) == Timestamp.min:
+                min_datetime = Timestamp("1677-09-22 00:12:43.145225Z")
+            if max_datetime.tz_localize(None) == Timestamp.max:
+                max_datetime = Timestamp("2262-04-10 23:47:16.854775807Z")
+            # Convert bounds to same tz
+            if Timestamp(min_datetime).tz is None:
+                min_datetime = Timestamp(min_datetime).tz_localize(tz)
+            if Timestamp(max_datetime).tz is None:
+                max_datetime = Timestamp(max_datetime).tz_localize(tz)
+
         return PandasColumn(
             name=check.str_param(name, "name"),
             constraints=[
-                ColumnDTypeInSetConstraint({"datetime64[ns]"}),
+                datetime_constraint,
                 InRangeColumnConstraint(
                     min_datetime, max_datetime, ignore_missing_vals=ignore_missing_vals
                 ),
